@@ -2,7 +2,7 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.6                                                               |
+// | Geeklog 1.8                                                               |
 // +---------------------------------------------------------------------------+
 // | lib-custom.php                                                            |
 // |                                                                           |
@@ -20,7 +20,7 @@
 // | not include lib-common.php in this file.                                  |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2000-2010 by the following authors:                         |
+// | Copyright (C) 2000-2011 by the following authors:                         |
 // |                                                                           |
 // | Authors: Tony Bibbs       - tony AT tonybibbs DOT com                     |
 // |          Blaine Lang      - blaine AT portalparts DOT com                 |
@@ -59,13 +59,6 @@ $_CST_VERBOSE = false;
  */
 require_once('custom/custom_cellular.php');
 
-/**
-* 日本語メール対応
-*
-* GL-1.4.1以降でUTF-8に変更されたメールの文字セットをISO-2022-JP(JIS)
-* に戻します。
-*/
-//require_once('custom/custom_mail_jp.php');
 
 /**
 * Sample PHP Block function
@@ -141,6 +134,7 @@ function CUSTOM_loginErrorHandler($msg='') {
 * - 'emailstory' (email story to a friend)
 * - 'loginblock' (login form in the side bar)
 * - 'loginform' (login form in the content area)
+* - 'search' (advanced search form; simple search is usually part of 'header')
 *
 * This function is called whenever PLG_templateSetVars is called, i.e. in
 * addition to the templates listed here, it may also be called from plugins.
@@ -150,7 +144,6 @@ function CUSTOM_loginErrorHandler($msg='') {
 * @return   void
 * @see      PLG_templateSetVars
 *
-*/
 function CUSTOM_templateSetVars($templatename, &$template)
 {
     // define a {hello_world} variable available in header.thtml and
@@ -168,6 +161,7 @@ function CUSTOM_templateSetVars($templatename, &$template)
         break;
     }
 }
+*/
 
 
 /*  Sample Custom Member Functions to create and update Custom Membership registration and profile
@@ -190,13 +184,26 @@ function CUSTOM_templateSetVars($templatename, &$template)
     - See notes below in the custom function about the template changes
 */
 
-/* Create any new records in additional tables you may have added  */
-/* Update any fields in the core GL tables for this user as needed */
-/* Called when user is first created */
-function CUSTOM_userCreate ($uid,$bulkimport=false)
+/**
+* Called when user is first created
+* Create any new records in additional tables you may have added
+* Update any fields in the core GL tables for this user as needed
+*
+* @param    int     $uid        user id - record already exists at this point
+* @param    boolean $bulkimport true during Batch User Import (admin/user.php)
+* @return   boolean             true on success, otherwise false
+*
+*/
+function CUSTOM_userCreate($uid, $bulkimport = false)
 {
     global $_CONF, $_TABLES;
 
+    if ($bulkimport) {
+        // the sample code in this function is written for the normal signup
+        // process; the $_POST variables are not set during bulk import
+        return true;
+    }
+
     // Ensure all data is prepared correctly before inserts, quotes may need to
     // be escaped with addslashes()
     $email = '';
@@ -236,7 +243,7 @@ function CUSTOM_userDelete($uid)
  * This function can now return any extra fields that need to be shown.
  * Output is then replaced in {customfields} -- This variable needs to be added
  * to your templates
- * Template: path_layout/users/profile/profile.thtml
+ * Template: path_layout/users/profile.thtml
  */
 function CUSTOM_userDisplay($uid)
 {
@@ -332,11 +339,8 @@ function CUSTOM_userForm ($msg = '')
     $submitbutton = '<input type="submit" value="Register Now!"' . XHTML . '>';
     $message = "<blockquote style=\"padding-top:10px;\"><b>Please complete the application below. Once you have completed the application, click the Register Now! button and the application will be processed immediately.</b></blockquote>";
 
-    $user_templates = new Template ($_CONF['path_layout'] . 'custom');
+    $user_templates = COM_newTemplate($_CONF['path_layout'] . 'custom');
     $user_templates->set_file('memberdetail', 'memberdetail.thtml');
-    $user_templates->set_var( 'xhtml', XHTML );
-    $user_templates->set_var('site_url', $_CONF['site_url']);
-    $user_templates->set_var('layout_url', $_CONF['layout_url']);
     $user_templates->set_var('post_url', $post_url);
     $user_templates->set_var('startblock', COM_startBlock("Custom Registration Example"));
     $user_templates->set_var('message', $message);
@@ -580,6 +584,9 @@ function CUSTOM_handleError($errno, $errstr, $errfile, $errline, $errcontext)
   * 日本語拡張版提供　PHPブロック関数およびカスタム関数
   */
 
+/* テーマ変数をセットする */
+require_once( 'custom/custom_templatesetvars.php' );
+
 /* 静的ページコンテンツの内容を返す */
 require_once( 'custom/custom_getstaticpage.php' );
 
@@ -601,4 +608,7 @@ require_once( 'custom/phpblock_themetester.php' );
 /* アクセス数を表示する */
 require_once( 'custom/phpblock_stats.php' );
 
+/* ユーザーエージェント判定のテンプレート変数を追加する */
+require_once( 'custom/useragent.class.php' );
+
 ?>
\ No newline at end of file
